// This file was generated by qtwaylandscanner
// source file is idle.xml

#ifndef QT_WAYLAND_IDLE
#define QT_WAYLAND_IDLE

#include "wayland-idle-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_kwin_idle
    {
    public:
        org_kde_kwin_idle(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_idle(struct ::org_kde_kwin_idle *object);
        org_kde_kwin_idle();

        virtual ~org_kde_kwin_idle();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_idle *object);

        struct ::org_kde_kwin_idle *object() { return m_org_kde_kwin_idle; }
        const struct ::org_kde_kwin_idle *object() const { return m_org_kde_kwin_idle; }
        static org_kde_kwin_idle *fromObject(struct ::org_kde_kwin_idle *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_kwin_idle_timeout *get_idle_timeout(struct ::wl_seat *seat, uint32_t timeout);

    private:
        struct ::org_kde_kwin_idle *m_org_kde_kwin_idle;
    };

    class  org_kde_kwin_idle_timeout
    {
    public:
        org_kde_kwin_idle_timeout(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_idle_timeout(struct ::org_kde_kwin_idle_timeout *object);
        org_kde_kwin_idle_timeout();

        virtual ~org_kde_kwin_idle_timeout();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_idle_timeout *object);

        struct ::org_kde_kwin_idle_timeout *object() { return m_org_kde_kwin_idle_timeout; }
        const struct ::org_kde_kwin_idle_timeout *object() const { return m_org_kde_kwin_idle_timeout; }
        static org_kde_kwin_idle_timeout *fromObject(struct ::org_kde_kwin_idle_timeout *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void release();
        void simulate_user_activity();

    protected:
        virtual void org_kde_kwin_idle_timeout_idle();
        virtual void org_kde_kwin_idle_timeout_resumed();

    private:
        void init_listener();
        static const struct org_kde_kwin_idle_timeout_listener m_org_kde_kwin_idle_timeout_listener;
        static void handle_idle(
            void *data,
            struct ::org_kde_kwin_idle_timeout *object);
        static void handle_resumed(
            void *data,
            struct ::org_kde_kwin_idle_timeout *object);
        struct ::org_kde_kwin_idle_timeout *m_org_kde_kwin_idle_timeout;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
